==> snf_3.3.0_webrelease.tar.gz: snf_3.3.0_webrelease/src/snfdc/param.h <==
      INTEGER mxinfi,mxitem,mxomeg,maxmode,maxatoms
      PARAMETER (mxinfi=100)      ! maximal number of input records
      PARAMETER (mxitem=12)       ! maximum number of fields in a split command
      PARAMETER (mxomeg=10)       ! maximum number of frequencies
      parameter(maxmode = 10)     ! maximum number of normal modes 
                                  ! if augmented to 50, problems with normal mode storage
                                  ! (intensities only mode) 
      parameter(maxatoms = 500)   ! maximum number of atoms
                                  ! (intensities only mode)

**
** message ids
**
      INTEGER bahtaskexit,bahtaskstop,bahfsyscal,bahfsysret,
     *bahshutdown
      PARAMETER (bahtaskexit=3,bahtaskstop=4)
      PARAMETER (bahfsyscal=5,bahfsysret=6,bahshutdown=7)
**
** global character variables
**
      CHARACTER*255 tempdir,mydir,logdir,restart,dcstat,
     * masterid,progdir,dcdir,eligpath
      CHARACTER*255 arpath,infi,incmd,title
      COMMON /chars/ tempdir,mydir,logdir,restart,dcstat,masterid,
     *arpath,eligpath,
     *title,infi(mxinfi),incmd(mxinfi),
     *masternode,progdir,dcdir
      CHARACTER*40 node,psmsg,masternode
**
** global real variables
**
      REAL*8 cstep,omeg
      COMMON /rname/ cstep,omeg(mxomeg)
**
** global integer variables
**
      INTEGER lt,lm,ll,li,lar,mytid,inrec,tid0,nstept,nvar,mxstep,
     *iprintf,progno,calcno,krest,icrap,ridft,
     *naus,natoms,plab,pco,cti,pst,lepath,pfr,pnm,
     *pmch,cmch,mmch,mastertid,updopt,pvmmch,isuhf,okok,
     *lb,ipol,rpast,exopt,ldc,smult,pdco,pvib
      COMMON /ints/ lt,lm,ll,li,lar,mytid,inrec,tid0,nstept,nvar,
     *mxstep,iprintf,progno,calcno,krest,icrap,ridft,
     *naus,natoms,plab,pco,cti,pst,lepath,
     *pmch,cmch,mmch,mastertid,updopt,pvmmch,isuhf,okok,
     *lb,ipol,rpast,exopt,ldc,smult,pdco,pvib
*
      INTEGER*4 istepa,istepb
*
* MPI communication
*
C#    INTEGER fsys_mpitag,fsys_taskstop,fsys_mnotify,fsys_restag
C#    PARAMETER (fsys_mpitag=700,fsys_taskstop=600,fsys_mnotify=500)
C#    PARAMETER (fsys_restag=800)

==> snf-4.0.0_webrelease.tar.gz: snf-4.0.0_webrelease/src/snfdc/param.h <==
      INTEGER mxinfi,mxitem,mxomeg,maxmode,maxatoms
      PARAMETER (mxinfi=100)      ! maximal number of input records
      PARAMETER (mxitem=12)       ! maximum number of fields in a split command
      PARAMETER (mxomeg=10)       ! maximum number of frequencies
      parameter(maxmode = 500)     ! maximum number of normal modes 
                                  ! if augmented to 50, problems with normal mode storage
                                  ! (intensities only mode) 
      parameter(maxatoms = 500)   ! maximum number of atoms
                                  ! (intensities only mode)

**
** message ids
**
      INTEGER bahtaskexit,bahtaskstop,bahfsyscal,bahfsysret,
     *bahshutdown
      PARAMETER (bahtaskexit=3,bahtaskstop=4)
      PARAMETER (bahfsyscal=5,bahfsysret=6,bahshutdown=7)
**
** global character variables
**
      CHARACTER*255 tempdir,mydir,logdir,restart,dcstat,
     * masterid,progdir,dcdir,cnopt,restadf
      CHARACTER*255 arpath,infi,incmd,title
      COMMON /chars/ tempdir,mydir,logdir,restart,dcstat,masterid,
     *arpath,cnopt,
     *title,infi(mxinfi),incmd(mxinfi),
     *masternode,progdir,dcdir, restadf
      CHARACTER*40 node,psmsg,masternode
**
** global real variables
**
      REAL*8 cstep,omeg
      COMMON /rname/ cstep,omeg(mxomeg)
**
** global integer variables
**
      INTEGER lt,lm,ll,li,lar,mytid,inrec,tid0,nstept,nvar,mxstep,
     *iprintf,progno,calcno,krest,icrap,ridft,isstep,
     *naus,natoms,plab,pco,cti,pst,lnopt,pfr,pnm,
     *pmch,cmch,mmch,mastertid,updopt,pvmmch,isuhf,okok,
     *lb,ipol,rpast,exopt,ldc,smult,pdco,pvib,lastqmatom,irescp,
     *pdip,ppol,pgra,pgtenlao,pgtenao,paten,pstepfl,pvmach
      COMMON /ints/ lt,lm,ll,li,lar,mytid,inrec,tid0,nstept,nvar,
     *mxstep,iprintf,progno,calcno,krest,icrap,ridft,isstep,
     *naus,natoms,plab,pco,cti,pst,lnopt,
     *pmch,cmch,mmch,mastertid,updopt,pvmmch,isuhf,okok,
     *lb,ipol,rpast,exopt,ldc,smult,pdco,pvib,lastqmatom,irescp,
     *pdip,ppol,pgra,pgtenlao,pgtenao,paten,pstepfl,pvmach
*
      INTEGER*4 istepa,istepb

**
** global logical variables
**
      logical para
      common para

*
* MPI communication
*
C#    INTEGER fsys_mpitag,fsys_taskstop,fsys_mnotify,fsys_restag
C#    PARAMETER (fsys_mpitag=700,fsys_taskstop=600,fsys_mnotify=500)
C#    PARAMETER (fsys_restag=800)
